==> zio-aws-ec2_2.12-5.17.145.1-sources.jar: zio/aws/ec2/model/GetCapacityReservationUsageResponse.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetCapacityReservationUsageResponse(
    nextToken: Option[String] = None,
    capacityReservationId: Option[String] = None,
    instanceType: Option[String] = None,
    totalInstanceCount: Option[Integer] = None,
    availableInstanceCount: Option[Integer] = None,
    state: Option[zio.aws.ec2.model.CapacityReservationState] = None,
    instanceUsages: Option[Iterable[zio.aws.ec2.model.InstanceUsage]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse = {
    import GetCapacityReservationUsageResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        capacityReservationId.map(value => value: java.lang.String)
      )(_.capacityReservationId)
      .optionallyWith(instanceType.map(value => value: java.lang.String))(
        _.instanceType
      )
      .optionallyWith(
        totalInstanceCount.map(value => value: java.lang.Integer)
      )(_.totalInstanceCount)
      .optionallyWith(
        availableInstanceCount.map(value => value: java.lang.Integer)
      )(_.availableInstanceCount)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        instanceUsages.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.instanceUsages)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetCapacityReservationUsageResponse.ReadOnly =
    zio.aws.ec2.model.GetCapacityReservationUsageResponse.wrap(buildAwsValue())
}
object GetCapacityReservationUsageResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetCapacityReservationUsageResponse =
      zio.aws.ec2.model.GetCapacityReservationUsageResponse(
        nextToken.map(value => value),
        capacityReservationId.map(value => value),
        instanceType.map(value => value),
        totalInstanceCount.map(value => value),
        availableInstanceCount.map(value => value),
        state.map(value => value),
        instanceUsages.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Option[String]
    def capacityReservationId: Option[String]
    def instanceType: Option[String]
    def totalInstanceCount: Option[Integer]
    def availableInstanceCount: Option[Integer]
    def state: Option[zio.aws.ec2.model.CapacityReservationState]
    def instanceUsages: Option[List[zio.aws.ec2.model.InstanceUsage.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getCapacityReservationId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("capacityReservationId", capacityReservationId)
    def getInstanceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceType", instanceType)
    def getTotalInstanceCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("totalInstanceCount", totalInstanceCount)
    def getAvailableInstanceCount: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("availableInstanceCount", availableInstanceCount)
    def getState
        : ZIO[Any, AwsError, zio.aws.ec2.model.CapacityReservationState] =
      AwsError.unwrapOptionField("state", state)
    def getInstanceUsages
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.InstanceUsage.ReadOnly]] =
      AwsError.unwrapOptionField("instanceUsages", instanceUsages)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse
  ) extends zio.aws.ec2.model.GetCapacityReservationUsageResponse.ReadOnly {
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
    override val capacityReservationId: Option[String] =
      scala.Option(impl.capacityReservationId()).map(value => value: String)
    override val instanceType: Option[String] =
      scala.Option(impl.instanceType()).map(value => value: String)
    override val totalInstanceCount: Option[Integer] =
      scala.Option(impl.totalInstanceCount()).map(value => value: Integer)
    override val availableInstanceCount: Option[Integer] =
      scala.Option(impl.availableInstanceCount()).map(value => value: Integer)
    override val state: Option[zio.aws.ec2.model.CapacityReservationState] =
      scala
        .Option(impl.state())
        .map(value => zio.aws.ec2.model.CapacityReservationState.wrap(value))
    override val instanceUsages
        : Option[List[zio.aws.ec2.model.InstanceUsage.ReadOnly]] = scala
      .Option(impl.instanceUsages())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.InstanceUsage.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse
  ): zio.aws.ec2.model.GetCapacityReservationUsageResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.124.3-sources.jar: zio/aws/ec2/model/GetCapacityReservationUsageResponse.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetCapacityReservationUsageResponse(
    nextToken: Option[String] = None,
    capacityReservationId: Option[String] = None,
    instanceType: Option[String] = None,
    totalInstanceCount: Option[Integer] = None,
    availableInstanceCount: Option[Integer] = None,
    state: Option[zio.aws.ec2.model.CapacityReservationState] = None,
    instanceUsages: Option[Iterable[zio.aws.ec2.model.InstanceUsage]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse = {
    import GetCapacityReservationUsageResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        capacityReservationId.map(value => value: java.lang.String)
      )(_.capacityReservationId)
      .optionallyWith(instanceType.map(value => value: java.lang.String))(
        _.instanceType
      )
      .optionallyWith(
        totalInstanceCount.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.totalInstanceCount)
      .optionallyWith(
        availableInstanceCount.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.availableInstanceCount)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        instanceUsages.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.instanceUsages)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetCapacityReservationUsageResponse.ReadOnly =
    zio.aws.ec2.model.GetCapacityReservationUsageResponse.wrap(buildAwsValue())
}
object GetCapacityReservationUsageResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.GetCapacityReservationUsageResponse =
      zio.aws.ec2.model.GetCapacityReservationUsageResponse(
        nextToken.map(value => value),
        capacityReservationId.map(value => value),
        instanceType.map(value => value),
        totalInstanceCount.map(value => value),
        availableInstanceCount.map(value => value),
        state.map(value => value),
        instanceUsages.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Option[String]
    def capacityReservationId: Option[String]
    def instanceType: Option[String]
    def totalInstanceCount: Option[Integer]
    def availableInstanceCount: Option[Integer]
    def state: Option[zio.aws.ec2.model.CapacityReservationState]
    def instanceUsages: Option[List[zio.aws.ec2.model.InstanceUsage.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getCapacityReservationId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("capacityReservationId", capacityReservationId)
    def getInstanceType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("instanceType", instanceType)
    def getTotalInstanceCount: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("totalInstanceCount", totalInstanceCount)
    def getAvailableInstanceCount: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("availableInstanceCount", availableInstanceCount)
    def getState
        : ZIO[Any, AwsError, zio.aws.ec2.model.CapacityReservationState] =
      AwsError.unwrapOptionField("state", state)
    def getInstanceUsages
        : ZIO[Any, AwsError, List[zio.aws.ec2.model.InstanceUsage.ReadOnly]] =
      AwsError.unwrapOptionField("instanceUsages", instanceUsages)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse
  ) extends zio.aws.ec2.model.GetCapacityReservationUsageResponse.ReadOnly {
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
    override val capacityReservationId: Option[String] =
      scala.Option(impl.capacityReservationId()).map(value => value: String)
    override val instanceType: Option[String] =
      scala.Option(impl.instanceType()).map(value => value: String)
    override val totalInstanceCount: Option[Integer] = scala
      .Option(impl.totalInstanceCount())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val availableInstanceCount: Option[Integer] = scala
      .Option(impl.availableInstanceCount())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val state: Option[zio.aws.ec2.model.CapacityReservationState] =
      scala
        .Option(impl.state())
        .map(value => zio.aws.ec2.model.CapacityReservationState.wrap(value))
    override val instanceUsages
        : Option[List[zio.aws.ec2.model.InstanceUsage.ReadOnly]] = scala
      .Option(impl.instanceUsages())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.InstanceUsage.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetCapacityReservationUsageResponse
  ): zio.aws.ec2.model.GetCapacityReservationUsageResponse.ReadOnly =
    new Wrapper(impl)
}
